@@ -29,6 +29,7 @@ else:
     timezone = pytz.timezone
     UTC = pytz.UTC
 
+from flask_babelex._compat import string_types
 
 _DEFAULT_LOCALE = Locale.parse('en')
 
@@ -73,6 +74,9 @@ class Babel(object):
         else:
             self._default_domain = default_domain
 
+        self.locale_selector_func = None
+        self.timezone_selector_func = None
+
         if app is not None:
             self.init_app(app)
 
@@ -104,9 +108,6 @@ class Babel(object):
         #:      otherwise the default for that language is used.
         self.date_formats = self._date_formats
 
-        self.locale_selector_func = None
-        self.timezone_selector_func = None
-
         if self._configure_jinja:
             app.jinja_env.filters.update(
                 datetimeformat=format_datetime,
@@ -251,7 +252,7 @@ def get_timezone():
                 if rv is None:
                     tzinfo = babel.default_timezone
                 else:
-                    if isinstance(rv, basestring):
+                    if isinstance(rv, string_types):
                         tzinfo = timezone(rv)
                     else:
                         tzinfo = rv
